#!/bin/sh
### BEGIN INIT INFO
# Provides:          MineCraftServer-daemon
# Required-Start:    $local_fs $remote_fs $network
# Required-Stop:     $local_fs $remote_fs $network
# Default-Start:     2 3 4 5
# Default-Stop:      0 1 6
# Short-Description: Start or stop the MineCraftServer-daemon.
### END INIT INFO
 
PKG_NAME="minecraft"
PKG_DIR=/usr/local/AppCentral/minecraft
RUN_AS="admin:administrators"
MCPATH="/volume1/Public/minecraft_server"
 
StartPkg(){ #starts the PKG
        /bin/echo -n "Starting $PKG_NAME"
        /bin/chown -R $RUN_AS $PKG_DIR
        /bin/chmod -R -t $PKG_DIR # make sure no system bits are set.
        /bin/chmod -R -s $PKG_DIR # make sure no system bits are set.
        [ -L $MCPATH ] && /bin/rm $MCPATH
        [ -d $MCPATH ] || /bin/mv $PKG_DIR/server $MCPATH
        [ -d $PKG_DIR/server ] && /bin/mv -f $PKG_DIR/server/* $MCPATH && /bin/rm $PKG_DIR/server
        cd $MCPATH
        VERSION=$(head -n 1 $MCPATH/version.txt)
        FORGE_VERSION=$(head -n 1 $MCPATH/forge-version.txt)
        URL="https://s3.amazonaws.com/Minecraft.Download/versions/${VERSION}/minecraft_server.${VERSION}.jar"
        FORGE_URL="http://files.minecraftforge.net/maven/net/minecraftforge/forge/${VERSION}-${FORGE_VERSION}/forge-${VERSION}-${FORGE_VERSION}-installer.jar"
        DAEMON="/usr/local/bin/java"
        DAEMON_OPTS=$(head -n 1 $MCPATH/deamon-opts.txt)
        SERVER_JAR="minecraft_server.${VERSION}.jar"
        [ -f $MCPATH/minecraft_server.${VERSION}.jar ] || wget --no-check-certificate $URL
        [ -f $MCPATH/forge-${VERSION}-${FORGE_VERSION}-universal.jar ] || wget --no-check-certificate $FORGE_URL || ${DAEMON} -jar forge-${VERSION}-${FORGE_VERSION}-installer.jar --installServer
        [ -f $MCPATH/forge-${VERSION}-${FORGE_VERSION}-universal.jar ] && SERVER_JAR="forge-${VERSION}-${FORGE_VERSION}-universal.jar"
        DAEMON_OPTS=" ${DAEMON_OPTS} -jar ${SERVER_JAR} nogui 2>&1"
        /bin/chown -R $RUN_AS $MCPATH
        /sbin/start-stop-daemon -S -b -n minecraft_server -c $RUN_AS -x ${DAEMON} --${DAEMON_OPTS}
        /bin/echo " Done ($(/bin/date))"
}
 
ShutdownPkg() { #kills a proces based on a PID
        output=`ps aux | grep -E 'minecraft_server|(forge-.*-universal)' | grep -v grep`
        set -- $output
        Pid=$1
        i=0
        /bin/kill $Pid
        /bin/echo -n " Waiting for ${PKG_NAME} to shut down: "
        while [ -d /proc/$Pid ]; do
                sleep 1
                let i+=1
                /bin/echo -n "$i, "
                if [ $i = 45 ]; then
                        /bin/echo -n " Tired of waiting, killing ${PKG_NAME} now"
                        /bin/kill -9 $Pid
                        /bin/rm -f $PID_FILE
                        break
                fi
        done
        /bin/echo "Done ($(/bin/date))"
}
 
case "$1" in
        start)
                StartPkg        
        ;;
        stop)
                /bin/echo "Shutting down ${PKG_NAME} at $(/bin/date)... "
                ShutdownPkg     #shutdown the package
        ;;
        restart)
                echo "Restarting $PKG_NAME"
                ShutdownPkg
                StartPkg
        ;;
        *)
                echo "Usage: $0 {start|stop|restart}"
esac
 
exit 0